<?php
use FluentForm\App\Modules\Component\Component;
/**
 * Declare common actions/filters/shortcodes
 */


/**
 * @var $app \FluentForm\Framework\Foundation\Application
 */

$component = new Component($app);
$component->addRendererActions();
$component->addFluentFormShortCode();
$component->addFluentFormDefaultValueParser();


$component = new \FluentForm\App\Modules\Component\Component($app);
$component->addFluentformSubmissionInsertedFilter();
$component->addIsRenderableFilter();

$app->addAction('init', function () use ($app) {
	(new \FluentForm\App\Modules\ProcessExteriorModule())->handleExteriorPages();
});

$elements = [
	'select',
	'input_checkbox',
	'input_image',
	'input_file',
	'address',
	'select_country',
	'gdpr_agreement',
	'terms_and_condition',
];

foreach ($elements as $element) {
	$event = 'fluentform_response_render_'.$element;
	$app->addFilter($event, function ($response, $field, $form_id) {

		if ($field['element'] == 'address' && isset($response->country)) {
			$countryList = getFluentFormCountryList();
			if (isset($countryList[$response->country])) {
				$response->country = $countryList[$response->country];
			}
		}

		if ($field['element'] == 'select_country') {
			$countryList = getFluentFormCountryList();
			if (isset($countryList[$response])) {
				$response = $countryList[$response];
			}
		}

		if (in_array($field['element'], array('gdpr_agreement', 'terms_and_condition'))) {
			$response = 'Accepted';
		}

		return \FluentForm\App\Modules\Form\FormDataParser::formatValue($response);
	}, 10, 3);
}

$app->addFilter('fluentform_response_render_input_repeat', function ($response, $field, $form_id) {
	return \FluentForm\App\Modules\Form\FormDataParser::formatRepeatFieldValue($response, $field, $form_id);
}, 10, 3);

$app->addFilter('fluentform_response_render_tabular_grid', function ($response, $field, $form_id) {
	return \FluentForm\App\Modules\Form\FormDataParser::formatTabularGridFieldValue($response, $field, $form_id);
}, 10, 3);

$app->addFilter('fluentform_response_render_input_name', function ($response) {
	return \FluentForm\App\Modules\Form\FormDataParser::formatName($response);
}, 10, 1);

$app->addFilter('fluentform_filter_insert_data', function($data) {
	$settings = get_option('_fluentform_global_form_settings', false);
	if (is_array($settings) && isset($settings['misc'])) {
		if (isset($settings['misc']['isIpLogingDisabled'])) {
			if ($settings['misc']['isIpLogingDisabled']) {
				unset($data['ip']);
			}
		}
	}
	return $data;
});


// Register api response log hooks
$app->addAction(
	'fluentform_after_submission_api_response_success',
	'fluentform_after_submission_api_response_success', 10, 6
);

$app->addAction(
	'fluentform_after_submission_api_response_failed',
	'fluentform_after_submission_api_response_failed', 10, 6
);

function fluentform_after_submission_api_response_success($form, $entryId, $data, $feed, $res, $msg = '') {
	try {

		$isDev = wpFluentForm()->getEnv() != 'production';
		if (!apply_filters('fluentform_api_success_log', $isDev,  $form, $feed)) return;

		wpFluent()->table('fluentform_submission_meta')->insert([
			'response_id' => $entryId,
			'form_id' => $form->id,
			'meta_key' => 'api_log',
			'value' =>  $msg,
			'name' => $feed->formattedValue['name'],
			'status' => 'success',
			'created_at' => date('Y-m-d H:i:s'),
			'updated_at' => date('Y-m-d H:i:s')
		]);
	} catch (Exception $e) {
		error_log($e->getMessage());
	}
}

function fluentform_after_submission_api_response_failed($form, $entryId, $data, $feed, $res, $msg = '') {
	try {

		$isDev = wpFluentForm()->getEnv() != 'production';
		if (!apply_filters('fluentform_api_failed_log', $isDev,  $form, $feed)) return;

		wpFluent()->table('fluentform_submission_meta')->insert([
			'response_id' => $entryId,
			'form_id' => $form->id,
			'meta_key' => 'api_log',
			'value' =>  json_encode($res),
			'name' => $feed->formattedValue['name'],
			'status' => 'failed',
			'created_at' => date('Y-m-d H:i:s'),
			'updated_at' => date('Y-m-d H:i:s'),
		]);
	} catch (Exception $e) {
		error_log($e->getMessage());
	}
}


$app->bindInstance(
	'fluentFormAsyncRequest',
	new \FluentForm\App\Services\WPAsync\FluentFormAsyncRequest($app),
	'FluentFormAsyncRequest',
	'FluentForm\App\Services\WPAsync\FluentFormAsyncRequest'
);


$app->addAction('shutdown', function() use ($app) {
    $fluentFormAsyncRequest = $app['fluentFormAsyncRequest'];
	if ($fluentFormAsyncRequest->hasActions()) {
		$fluentFormAsyncRequest->dispatch();
	}
});


$app->addFilter('fluentform-disabled_analytics', function ($status) {
    $settings = get_option('_fluentform_global_form_settings');
    if(isset($settings['misc']['isAnalyticsDisabled']) && $settings['misc']['isAnalyticsDisabled']) {
        return true;
    }
    return $status;
});

$app->addAction('fluentform_before_form_render', function ($form) {
    (new \FluentForm\App\Modules\Form\Settings\FormCssJs)->addJs($form);
});

$app->addAction('fluentform_after_form_render', function ($form) {
    (new \FluentForm\App\Modules\Form\Settings\FormCssJs)->addCss($form);
});
