<?php
namespace FluentForm\App\Modules;

use FluentForm\App\Modules\Acl\Acl;
use FluentForm\App\Databases\DatabaseMigrator;

class Activator
{
	/**
	 * This method will be called on plugin activation
	 * @return void
	 */
	public function handleActivation($network_wide)
	{
        global $wpdb;
        if ($network_wide) {
            // Retrieve all site IDs from this network (WordPress >= 4.6 provides easy to use functions for that).
            if (function_exists('get_sites') && function_exists('get_current_network_id')) {
                $site_ids = get_sites(array('fields' => 'ids', 'network_id' => get_current_network_id()));
            } else {
                $site_ids = $wpdb->get_col("SELECT blog_id FROM $wpdb->blogs WHERE site_id = $wpdb->siteid;");
            }
            // Install the plugin for all these sites.
            foreach ($site_ids as $site_id) {
                switch_to_blog($site_id);
                $this->migrate();
                restore_current_blog();
            }
        } else {
            $this->migrate();
        }
	}

	public function migrate()
    {
        // We are going to migrate all the database tables here.
        DatabaseMigrator::run();
        // Assign fluentform permission set.
        Acl::setPermissions();

        $this->setDefaultGlobalSettings();
        $this->setCurrentVersion();
    }


	private function setDefaultGlobalSettings()
	{
		if(!get_option('_fluentform_global_form_settings')) {
			update_option('__fluentform_global_form_settings', array(
				'layout' => array(
					'labelPlacement' => 'top',
					'helpMessagePlacement' => 'with_label',
					'errorMessagePlacement' => 'inline',
					'cssClassName' => ''
				)
			));
		}
	}

	private function setCurrentVersion()
	{
		update_option('_fluentform_installed_version', FLUENTFORM_VERSION);
	}
}
