<?php

namespace FluentForm\App\Modules\Registerer;

use FluentForm\App\Modules\AddOnModule;
use FluentForm\App\Modules\DocumentationModule;
use FluentForm\View;
use FluentForm\Framework\Foundation\Application;

class Menu
{
    /**
     * @var \FluentForm\Framework\Foundation\Application
     */
    protected $app;

    /**
     * Menu constructor.
     *
     * @param \FluentForm\Framework\Foundation\Application $application
     */
    public function __construct(Application $application)
    {
        $this->app = $application;

        $this->app->addFilter('fluentform_form_settings_menu', array(
            $this, 'filterFormSettingsMenu'
        ), 10, 2);
    }

    /**
     * Register menu and sub-menus.
     */
    public function register()
    {
        $dashBoardCapability = apply_filters('fluentform_dashboard_capability', 'fluentform_settings_manager');
        $settingsCapability = apply_filters('fluentform_settings_capability', 'fluentform_settings_manager');

        if (!current_user_can($dashBoardCapability) && !current_user_can($settingsCapability)) {
            return;
        }

        if (defined('FLUENTFORMPRO')) {
            $title = __('Fluent Form Pro', 'fluentform');
        } else {
            $title = __('Fluent Form', 'fluentform');
        }


        add_menu_page(
            $title,
            $title,
            $dashBoardCapability,
            'fluent_forms',
            array($this, 'renderFormAdminRoute'),
            $this->getMenuIcon(),
            25
        );


        add_submenu_page(
            'fluent_forms',
            __('All Forms', 'fluentform'),
            __('All Forms', 'fluentform'),
            $dashBoardCapability,
            'fluent_forms',
            array($this, 'renderFormAdminRoute')
        );

        add_submenu_page(
            'fluent_forms',
            __('New Form', 'fluentform'),
            __('New Form', 'fluentform'),
            $settingsCapability,
            'fluent_forms#add=1',
            array($this, 'renderFormAdminRoute')
        );

        // Register entries intermediary page
        add_submenu_page(
            'fluent_forms',
            __('Entries', 'fluentform'),
            __('Entries', 'fluentform'),
            $settingsCapability,
            'fluent_forms#entries',
            array($this, 'renderFormAdminRoute')
        );

        // Register import/export sub menu page.
        add_submenu_page(
            'fluent_forms',
            __('Export/Import', 'fluentform'),
            __('Export/Import', 'fluentform'),
            $settingsCapability,
            'fluent_forms_transfer',
            array($this, 'renderTransfer')
        );

        // Register global settings sub menu page.
        add_submenu_page(
            'fluent_forms',
            __('Settings', 'fluentform'),
            __('Settings', 'fluentform'),
            $settingsCapability,
            'fluent_forms_settings',
            array($this, 'renderGlobalSettings')
        );

        // Register Add-Ons
        add_submenu_page(
            'fluent_forms',
            __('Add Ons', 'fluentform'),
            __('Add Ons', 'fluentform'),
            $dashBoardCapability,
            'fluent_form_add_ons',
            array($this, 'renderAddOns')
        );

        // Register Documentation
        add_submenu_page(
            'fluent_forms',
            __('Get Help', 'fluentform'),
            __('Get Help', 'fluentform'),
            $dashBoardCapability,
            'fluent_forms_docs',
            array($this, 'renderDocs')
        );

        $this->commonAction();

    }


    private function getMenuIcon()
    {
        return 'data:image/svg+xml;base64,' . base64_encode('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><defs><style>.cls-1{fill:#fff;}</style></defs><title>dashboard_icon</title><g id="Layer_2" data-name="Layer 2"><g id="Layer_1-2" data-name="Layer 1"><path class="cls-1" d="M15.57,0H4.43A4.43,4.43,0,0,0,0,4.43V15.57A4.43,4.43,0,0,0,4.43,20H15.57A4.43,4.43,0,0,0,20,15.57V4.43A4.43,4.43,0,0,0,15.57,0ZM12.82,14a2.36,2.36,0,0,1-1.66.68H6.5A2.31,2.31,0,0,1,7.18,13a2.36,2.36,0,0,1,1.66-.68l4.66,0A2.34,2.34,0,0,1,12.82,14Zm3.3-3.46a2.36,2.36,0,0,1-1.66.68H3.21a2.25,2.25,0,0,1,.68-1.64,2.36,2.36,0,0,1,1.66-.68H16.79A2.25,2.25,0,0,1,16.12,10.53Zm0-3.73a2.36,2.36,0,0,1-1.66.68H3.21a2.25,2.25,0,0,1,.68-1.64,2.36,2.36,0,0,1,1.66-.68H16.79A2.25,2.25,0,0,1,16.12,6.81Z"/></g></g></svg>');
    }

    public function renderFormAdminRoute()
    {
        if (isset($_GET['route']) && isset($_GET['form_id'])) {

            wp_enqueue_style('fluentform_settings_global', fluentformMix("css/settings_global.css"), array(), FLUENTFORM_VERSION,
                'all');

            wp_enqueue_script(
                'clipboard',
                $this->app->publicUrl('libs/clipboard.min.js'),
                array(),
                false,
                true
            );

            wp_enqueue_script(
                'copier',
                $this->app->publicUrl('js/copier.js'),
                array(),
                false,
                true
            );

            $form_id = intval($_GET['form_id']);

            $formAdminMenus = array(
                'editor'   => array(
                    'slug'  => 'editor',
                    'title' => __('Editor', 'fluentform')
                ),
                'settings' => array(
                    'slug'      => 'settings',
                    'hash'      => 'basic_settings',
                    'title'     => __('Settings & Integrations', 'fluentform'),
                    'sub_route' => 'form_settings'
                ),
                'entries'  => array(
                    'slug'  => 'entries',
                    'hash'  => '/',
                    'title' => __('Entries', 'fluentform')
                )
            );

            $formAdminMenus = apply_filters('fluentform_form_admin_menu', $formAdminMenus, $form_id);

            $form = wpFluent()->table('fluentform_forms')->find($form_id);

            if (!$form) {
                echo __("<h2>No form found</h2>", 'fluentform');
                die();
            }

            View::render('admin.form.form_wrapper', array(
                'route'      => sanitize_text_field($_GET['route']),
                'form_id'    => $form_id,
                'form'       => $form,
                'menu_items' => $formAdminMenus
            ));

            return;
        }

        $this->renderForms();
    }

    public function renderSettings($form_id)
    {
        $settingsMenus = array(
            'form_settings'         => array(
                'title' => __('Form Settings', 'fluentform'),
                'slug'  => 'form_settings',
                'hash'  => 'basic_settings'
            ),
            'email_notifications'   => array(
                'title' => __('Email Notifications', 'fluentform'),
                'slug'  => 'form_settings',
                'hash'  => 'email_notifications'
            ),
            'other_confirmations'   => array(
                'title' => __('Other Confirmations', 'fluentform'),
                'slug'  => 'form_settings',
                'hash'  => 'other_confirmations'
            ),
            'mailchimp_integration' => array(
                'title' => __('MailChimp', 'fluentform'),
                'slug'  => 'form_settings',
                'hash'  => 'mailchimp_integration'
            ),
            'slack'                 => array(
                'title' => __('Slack', 'fluentform'),
                'slug'  => 'form_settings',
                'hash'  => 'slack'
            )
        );

        if (!defined('FLUENTFORMPRO')) {
            $settingsMenus['other_integrations'] = array(
                'title' => __('Other Integrations', 'fluentform'),
                'slug'  => 'form_settings',
                'hash'  => 'integrations_promo'
            );
        }




        $settingsMenus = apply_filters('fluentform_form_settings_menu', $settingsMenus, $form_id);

        $externalMenuItems = [];
        foreach ($settingsMenus as $key => $menu) {
            if (empty($menu['hash'])) {
                unset($settingsMenus[$key]);
                $externalMenuItems[$key] = $menu;
            }
        }

        $settingsMenus['custom_css_js'] = array(
            'title' => __('Custom CSS/JS', 'fluentform'),
            'slug' => 'form_settings',
            'hash' => 'custom_css_js'
        );

        $settingsMenus = array_filter(array_merge($settingsMenus, $externalMenuItems));


        $currentRoute = sanitize_text_field($this->app->request->get('sub_route', ''));

        View::render('admin.form.settings_wrapper', array(
            'form_id'           => $form_id,
            'settings_menus'    => $settingsMenus,
            'current_sub_route' => $currentRoute
        ));
    }

    /**
     * Remove the inactive addOn menu items
     * @param  string $addOn
     * @return boolean
     */
    public function filterFormSettingsMenu($settingsMenus, $form_id)
    {
        if (array_key_exists('mailchimp_integration', $settingsMenus)) {
            $option = (array)get_option('_fluentform_mailchimp_details');
            if (!isset($option['status']) || !$option['status']) {
                unset($settingsMenus['mailchimp_integration']);
            }
        }

        return $settingsMenus;
    }

    public function renderFormSettings($form_id)
    {
        $version = $this->app->getVersion();

        if (function_exists('wp_enqueue_editor')) {
            wp_enqueue_editor();
        }

        wp_enqueue_script('fluentform_form_settings', fluentformMix("js/form_settings_app.js"), array('jquery'), FLUENTFORM_VERSION,
            false);

        wp_localize_script('fluentform_form_settings', 'FluentFormApp', array(
            'form_id' => $form_id,
            'plugin'  => $this->app->getSlug(),
            'hasPro'  => defined('FLUENTFORMPRO'),
            'hasPDF'  => class_exists('FluentFormPdf\FluentFormPdf'),
            'ace_path_url' => $this->app->publicUrl('libs/ace')
        ));

        View::render('admin.form.settings', array(
            'form_id' => $form_id
        ));
    }

    public function renderForms()
    {
        $version = FLUENTFORM_VERSION;


        wp_enqueue_script('fluent_all_forms', fluentformMix("js/fluent-all-forms-admin.js"), array('jquery'), FLUENTFORM_VERSION,
            false);

        wp_enqueue_style('fluent_all_forms', fluentformMix("css/fluent-all-forms.css"), array(), FLUENTFORM_VERSION, 'all');

        $formsCount = wpFluent()->table('fluentform_forms')->count();

        wp_localize_script('fluent_all_forms', 'FluentFormApp', array(
            'plugin'             => $this->app->getSlug(),
            'formsCount'         => $formsCount,
            'hasPro'  => defined('FLUENTFORMPRO'),
            'adminUrl'           => admin_url('admin.php?page=fluent_forms'),
            'isDisableAnalytics' => apply_filters('fluentform-disabled_analytics', false)
        ));

        View::render('admin.all_forms', array());
    }

    public function renderEditor($form_id)
    {
        $this->enqueueEditorAssets();
        View::render('admin.form.editor', array(
            'plugin'  => $this->app->getSlug(),
            'form_id' => $form_id
        ));
    }

    public function renderDocs()
    {
        echo (new DocumentationModule())->render();
    }

    public function renderAddOns()
    {
        echo (new AddOnModule())->render();
    }

    private function enqueueEditorAssets()
    {
        $pluginSlug = $this->app->getSlug();
        $version = FLUENTFORM_VERSION;

        wp_enqueue_script('fluentform_editor_script', fluentformMix("js/fluent-forms-editor.js"), ['jquery'], $version,
            false);

        wp_enqueue_style('fluentform_editor_style', fluentformMix("css/fluent-forms-admin-sass.css"), [], $version,
            'all');

        wp_enqueue_style('fluentform_editor_sass', fluentformMix("css/fluent-forms-admin.css"), [], $version, 'all');

        $formId = intval($_GET['form_id']);
        wp_localize_script('fluentform_editor_script', 'FluentFormApp', array(
            'plugin'            => $pluginSlug,
            'form_id'           => $formId,
            'plugin_public_url' => $this->app->publicUrl(),
            'preview_url'       => $this->getFormPreviewUrl($formId),
            'form'              => wpFluent()->table('fluentform_forms')->find($formId),

            'countries' => $this->app->load(
                $this->app->appPath('Services/FormBuilder/CountryNames.php')
            ),

            'element_customization_settings' => $this->app->load(
                $this->app->appPath('Services/FormBuilder/ElementCustomization.php')
            ),

            'validation_rule_settings' => $this->app->load(
                $this->app->appPath('Services/FormBuilder/ValidationRuleSettings.php')
            ),

            'element_search_tags' => $this->app->load(
                $this->app->appPath('Services/FormBuilder/ElementSearchTags.php')
            ),

            'element_settings_placement' => $this->app->load(
                $this->app->appPath('Services/FormBuilder/ElementSettingsPlacement.php')
            ),
        ));
    }

    /**
     * Render global settings page.
     *
     * @throws \Exception
     */
    public function renderGlobalSettings()
    {
        $version = FLUENTFORM_VERSION;

        wp_enqueue_style(
            'fluentform_settings_global',
            fluentformMix("css/settings_global.css"),
            [], $version, 'all'
        );

        // Fire an event letting others know the current component
        // that fluentform is rendering for the global settings
        // page. So that they can hook and load their custom
        // components on this page dynamically & easily.
        // N.B. native 'components' will always use
        // 'settings' as their current component.
        $currentComponent = apply_filters('fluentform_global_settings_current_component',
            $this->app->request->get('component', 'settings')
        );

        $components = apply_filters('fluentform_global_settings_components', [
            'reCAPTCHA' => [
                'hash'  => 're_captcha',
                'title' => 'reCAPTCHA',
            ],
            'mailchimp' => [
                'hash'  => 'mailchimp',
                'title' => 'MailChimp',
            ]
        ]);

        View::render('admin.settings.index', [
            'components'       => $components,
            'currentComponent' => $currentComponent
        ]);
    }

    public function renderTransfer()
    {
        wp_enqueue_style(
            'fluentform_settings_global',
            fluentformMix("css/settings_global.css"),
            [], FLUENTFORM_VERSION, 'all'
        );

        wp_enqueue_script('fluentform-transfer-js',
            fluentformMix("js/fluentform-transfer.js"),
            ['jquery'], FLUENTFORM_VERSION, false
        );

        $forms = wpFluent()->table('fluentform_forms')
            ->orderBy('id', 'desc')
            ->select(['id', 'title'])
            ->get();

        wp_localize_script('fluentform-transfer-js', 'FluentFormApp', [
            'plugin' => $this->app->getSlug(),
            'forms'  => $forms
        ]);

        View::render('admin.transfer.index');
    }


    private function getFormPreviewUrl($form_id)
    {
        return site_url('?fluentform_pages=1&preview_id=' . $form_id) . '#ff_preview';
    }

    public function addPreviewButton($formId)
    {
        echo '<a target="_blank" class="el-button el-button--primary el-button--small" href="' . $this->getFormPreviewUrl($formId) . '">Preview</a>';
    }

    public function addCopyShortcodeButton($formId)
    {
        echo '<button style="background:#dedede;color:#545454;padding:5px;" title="Click to Copy" class="btn copy" data-clipboard-text=\'[fluentform id="' . $formId . '"]\'><i class="dashicons dashicons-admin-page" style="color:#eee;text-shadow:#000 -1px 1px 1px;"></i> [fluentform id="' . $formId . '"]</button>';
        return;

        // Following code is required
        echo '<button style="background:#dedede;color:#545454;padding:5px;" title="Click to Copy" class="btn copy" data-clipboard-text=\'[fluentform id="' . $formId . '"]\'>
            <?xml version="1.0" encoding="iso-8859-1"?><svg style="height:20px;width:20px;vertical-align:middle;" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 512 512" style="enable-background:new 0 0 512 512;" xml:space="preserve"><g><g><g><path d="M456.533,153.6H422.4v-51.2c-0.028-23.553-19.114-42.639-42.667-42.667h-35.706C340.435,49.534,330.813,42.7,320,42.667h-17.067V25.6c-0.015-14.132-11.468-25.585-25.6-25.6h-102.4c-14.132,0.015-25.585,11.468-25.6,25.6v17.067h-17.067c-10.813,0.033-20.435,6.868-24.028,17.067H72.533C48.981,59.761,29.894,78.847,29.867,102.4v332.8c0.028,23.553,19.114,42.639,42.667,42.667h102.4v8.533c0.015,14.132,11.468,25.585,25.6,25.6h256c14.132-0.015,25.585-11.468,25.6-25.6V179.2C482.118,165.068,470.665,153.615,456.533,153.6z M166.4,25.6c0.006-4.71,3.823-8.527,8.533-8.533h102.4c4.71,0.006,8.527,3.823,8.533,8.533v17.067H166.4V25.6z M123.733,68.267c0.006-4.71,3.823-8.527,8.533-8.533H320c4.71,0.006,8.527,3.823,8.533,8.533V102.4c-0.006,4.71-3.823,8.527-8.533,8.533H132.267c-4.71-0.006-8.527-3.823-8.533-8.533V68.267z M174.933,179.2v281.6h-102.4c-14.132-0.015-25.585-11.468-25.6-25.6V102.4c0.015-14.132,11.468-25.585,25.6-25.6h34.133v25.6c0.015,14.132,11.468,25.585,25.6,25.6H320c14.132-0.015,25.585-11.468,25.6-25.6V76.8h34.133c14.132,0.015,25.585,11.468,25.6,25.6v51.2h-204.8C186.401,153.615,174.949,165.068,174.933,179.2z M465.067,486.4c-0.006,4.71-3.823,8.527-8.533,8.533h-256c-4.71-0.006-8.527-3.823-8.533-8.533V179.2c0.006-4.71,3.823-8.527,8.533-8.533h256c4.71,0.006,8.527,3.823,8.533,8.533V486.4z"/><path d="M405.333,256h-153.6c-4.713,0-8.533,3.82-8.533,8.533s3.82,8.533,8.533,8.533h153.6c4.713,0,8.533-3.82,8.533-8.533S410.046,256,405.333,256z"/><path d="M405.333,298.667h-153.6c-4.713,0-8.533,3.82-8.533,8.533s3.82,8.533,8.533,8.533h153.6c4.713,0,8.533-3.82,8.533-8.533S410.046,298.667,405.333,298.667z"/><path d="M405.333,341.333h-153.6c-4.713,0-8.533,3.82-8.533,8.533s3.82,8.533,8.533,8.533h153.6c4.713,0,8.533-3.82,8.533-8.533S410.046,341.333,405.333,341.333z"/><path d="M405.333,384h-153.6c-4.713,0-8.533,3.821-8.533,8.533c0,4.713,3.82,8.533,8.533,8.533h153.6c4.713,0,8.533-3.821,8.533-8.533C413.867,387.821,410.046,384,405.333,384z"/></g></g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g><g></g></svg>
            [fluentform id="' . $formId . '"]
        </button>';
    }

    public function commonAction()
    {
        $fluentFormPages = array(
            'fluent_forms',
            'fluent_forms_transfer',
            'fluent_forms_settings',
            'fluent_form_add_ons',
            'fluent_forms_docs'
        );
        if (isset($_GET['page']) && in_array($_GET['page'], $fluentFormPages)) {
            // Let's deregister existing vuejs by other devs
            // Other devs should not regis
            add_action('admin_print_scripts', function () {
                wp_dequeue_script('vuejs');
                wp_dequeue_script('vue');
                wp_deregister_script('elementor-admin-app');
            });
        }
    }

    public function renderGlobalMenu()
    {
        View::render('admin.global_menu', array());
    }
}
