<?php

namespace FluentForm\App\Services\FormBuilder\Notifications;

use FluentForm\App\Services\ConditionAssesor;
use FluentForm\Framework\Foundation\Application;
use FluentForm\App\Services\FormBuilder\NotificationParser;

class EmailNotificationActions
{
	protected $app = null;

	public function __construct(Application $app)
	{
		$this->app = $app;
	}

	public function register()
	{
		$this->app->addAction('fluentform_send_email', array($this, 'sendEmail'), 10, 3);
		$this->app->addAction('fluentform_send_email_async', array($this, 'sendEmailAsync'), 10, 3);
		$this->app->addAction('fluentform_submission_inserted', array($this, 'handleNotification'), 10, 3);
	}

	public function sendEmail($entryId, $data, $form)
	{
		$notifications = wpFluent()
			->table( 'fluentform_form_meta' )
			->where( 'form_id', $form->id )
			->where( 'meta_key', 'notifications' )
			->get();

		$enabledNotifications = array();
		foreach ( $notifications as $key => $notification ) {
			$notification = json_decode( $notification->value, true );
			if ( $notification['enabled'] && ConditionAssesor::evaluate( $notification, $data ) ) {
				$enabledNotifications[] = $notification;
			}
		}

		if ($enabledNotifications) {
			$enabledNotifications = NotificationParser::parse(
				$enabledNotifications, $entryId, $data, $form
			);

			$notifier = $this->app->make(
				'FluentForm\App\Services\FormBuilder\Notifications\EmailNotification'
			);

			foreach ($enabledNotifications as $notification) {

				$notification = $this->app->applyFilters(
					'fluentform_filter_email_notification',
					$notification,
					$data,
					$form,
					$entryId
				);

				$notifier->notify($notification, $data, $form, $entryId);
			}
		}
	}

	public function sendEmailAsync($entryId, $data, $form)
	{
		$this->app['fluentFormAsyncRequest']->shouldBeAsync('fluentform_send_email', [
				'form_data' => $data,
				'form_id' => $form->id,
				'entry_id' => $entryId
			]
		);
	}

	public function handleNotification($entryId, $data, $form)
	{
		// To send the email on asynchronously, we need to change the false to true or add a filter for it.
		if ($this->app->applyFilters('fluentform_sending_email_async', false, $entryId, $data, $form)) {
			return $this->app->doAction('fluentform_send_email_async', $entryId, $data, $form);
		}
		return $this->app->doAction('fluentform_send_email', $entryId, $data, $form);
	}
}
