<?php

namespace FluentForm\App\Services\Integrations\MailChimp;

use FluentForm\Framework\Foundation\Application;
use FluentForm\App\Services\Integrations\MailChimp\MailChimpIntegration;

class MailChimpNotificationActions
{
	protected $app = null;

	public function __construct(Application $app)
	{
		$this->app = $app;
	}

	public function register()
	{
		if ($this->isMailChimpEnabled()) {
			$this->app->addAction('fluentform_subscribe_mailchimp', array($this, 'notify'), 10, 3);
			$this->app->addAction('fluentform_subscribe_mailchimp_async', array($this, 'notifyAsync'), 10, 3);
			$this->app->addAction('fluentform_submission_inserted', array($this, 'handleNotification'), 10, 3);
		}
	}

	public function notify($entryId, $data, $form)
	{
		(new MailChimpIntegration($this->app))->subscribe($data, $form, $entryId);
	}

	public function notifyAsync($entryId, $data, $form)
	{
		$this->app['fluentFormAsyncRequest']->shouldBeAsync('fluentform_subscribe_mailchimp', [
				'form_data' => $data,
				'form_id' => $form->id,
				'entry_id' => $entryId
			]
		);
	}

	public function handleNotification($entryId, $data, $form)
	{
		if ($this->app->applyFilters('fluentform_subscribing_mailchimp', true, $entryId, $data, $form)) {
			return $this->app->doAction('fluentform_subscribe_mailchimp_async', $entryId, $data, $form);
		}
		return $this->app->doAction('fluentform_subscribe_mailchimp', $entryId, $data, $form);
	}

	protected function isMailChimpEnabled()
	{
	    if ($settings = get_option('_fluentform_mailchimp_details')) {
	        return (isset($settings['status']) && $settings['status']);
	    }
	}
}
