<?php

namespace FluentForm\App\Services\Integrations\Slack;

use FluentForm\Framework\Foundation\Application;
use FluentForm\App\Services\Integrations\Slack\Slack;

class SlackNotificationActions
{
	protected $app = null;

	public function __construct(Application $app)
	{
		$this->app = $app;
	}

	public function register()
	{
		if ($this->isSlackEnabled()) {
			$this->app->addAction('fluentform_subscribe_slack', array($this, 'notify'), 10, 3);
			$this->app->addAction('fluentform_subscribe_slack_async', array($this, 'notifyAsync'), 10, 3);
			$this->app->addAction('fluentform_submission_inserted', array($this, 'handleNotification'), 10, 3);
		}
	}

	public function notify($entryId, $data, $form)
	{
		Slack::notify($data, $form, $entryId);
	}

	public function notifyAsync($entryId, $data, $form)
	{
		$this->app['fluentFormAsyncRequest']->shouldBeAsync('fluentform_subscribe_slack', [
				'form_data' => $data,
				'form_id' => $form->id,
				'entry_id' => $entryId
			]
		);
	}

	public function handleNotification($entryId, $data, $form)
	{
		if ($this->app->applyFilters('fluentform_subscribing_slack', true, $entryId, $data, $form)) {
			return $this->app->doAction('fluentform_subscribe_slack_async', $entryId, $data, $form);
		}
		return $this->app->doAction('fluentform_subscribe_slack', $entryId, $data, $form);
	}

	protected function isSlackEnabled()
	{
		$settings = wpFluent()
	    ->table('fluentform_form_meta')
	    ->where('form_id', $this->app->request->get('form_id'))
	    ->where('meta_key', 'slack')
	    ->first();

	    if ($settings) {
	        $settings = json_decode($settings->value, true);
	        return (isset($settings['enabled']) && $settings['enabled']);
        }
	}
}
